<?php
/**
* @version $Id: profilemyjspace.php $
* @version		3.0.0 06/08/2019
* @package		plg_user_profilemyjspace
* @author       Bernard Saulm
* @copyright	Copyright (C) 2011 - 2019 Bernard Saulm
* @license      GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
*/

defined('_JEXEC') or die;

class plgUserProfileMyjspace extends JPlugin
{
	public function __construct(& $subject, $config)
	{
		parent::__construct($subject, $config);
	}

	/**
	 * @param	string	The context for the data
	 * @param	int		The user id
	 * @param	object
	 * @return	boolean
	 * @since	1.6
	 */
	function onContentPrepareData($context, $data)
	{
		// Check we are manipulating a valid form.
		if (!in_array($context, array('com_users.profile','com_users.user'))) {
			return true;
		}

		// Check if component BS Myjspace installed
		if (!file_exists(JPATH_ROOT.'/components/com_myjspace/helpers/user.php'))
			return true;

		// BS MyJspace data API
        require_once JPATH_ROOT.'/components/com_myjspace/helpers/user.php';

		// Personal page user info
		$userId = isset($data->id) ? $data->id : 0;

		if ($userId != 0) {
			$pparams = JComponentHelper::getParams('com_myjspace');
			$linktype = $pparams->get('link_folder_print', 0);

			list($list_page_tab, $url) = BSHelperUser::GetUserUrl($userId, $linktype, false);
			$data->profilemyjspace['link'] = $url;

			if (!JHtml::isRegistered('users.link')) {
				JHtml::register('users.link', array(__CLASS__, 'link'));
			}
		}

		return true;
	}

	/**
	 * @param	JForm	The form to be altered.
	 * @param	array	The associated data for the form.
	 * @return	boolean
	 * @since	1.6
	 */
	function onContentPrepareForm($form, $data)
	{
		// Load user_profile plugin language
		$lang = JFactory::getLanguage();
		$lang->load('plg_user_profilemyjspace', JPATH_ADMINISTRATOR);

		$jinput = JFactory::getApplication()->input;

		if (!($form instanceof JForm)) {
			$this->_subject->setError('JERROR_NOT_A_FORM');
			return false;
		}

		// Check we are manipulating a valid form.
		if (!in_array($form->getName(), array('com_users.profile','com_users.user'))) {
			return true;
		}

		// If not in display mode only (no edit)
		if ($jinput->get('layout', '', 'STRING') != '' && $form->getName() == 'com_users.profile') {
			return true;
		}

		// Check if component BS Myjspace installed
		if (!file_exists(JPATH_ROOT.'/components/com_myjspace/helpers/user.php'))
			return true;

		// If no personal page
		if (!isset($data->profilemyjspace['link']))
			return true;

		if ($form->getName() == 'com_users.profile' || $form->getName() == 'com_users.user') {
			// Add the profile fields to the form.
			JForm::addFormPath(dirname(__FILE__).'/profiles');
			$form->loadFile('profile', false);

			$form->setFieldAttribute('link', 'required', false, 'profilemyjspace');
		}
	}

	/**
	 * Returns a anchor tag generated from a given value
	 *
	 * @param   string  $value  url to use
	 *
	 * @return mixed|string
	 */
	public static function link($value)
	{
		$user = JFactory::getUser();
		$pparams = JComponentHelper::getParams('com_myjspace');
		$linktype = $pparams->get('link_folder_print', 0);

		list($list_page_tab, $url) = BSHelperUser::GetUserUrl($user->id, $linktype, false);

		if (count($list_page_tab) > 1) {
			return '<a href="'.$value.'">'.JText::_('PLG_USER_PROFILEMYJSPACE_PAGES').'</a>';
		} else {
			return '<a href="'.$value.'">'.$list_page_tab[0]['pagename'].'</a>';
		}
	}
}
 